@@ -10,10 +10,12 @@
 #include <QObject>
 #include <QQmlListProperty>
 
+#include "categoriesmodel.h"
 #include "enginebase.h"
 #include "entry.h"
 #include "errorcode.h"
 #include "provider.h"
+#include "searchpresetmodel.h"
 #include "transaction.h"
 
 class EnginePrivate;
@@ -33,12 +35,12 @@ class Engine : public KNSCore::EngineBase
     Q_PROPERTY(QString name READ name NOTIFY configFileChanged)
     Q_PROPERTY(bool isValid READ isValid NOTIFY configFileChanged)
 
-    Q_PROPERTY(QObject *categories READ categories NOTIFY categoriesChanged)
+    Q_PROPERTY(CategoriesModel *categories READ categories NOTIFY categoriesChanged)
     Q_PROPERTY(QStringList categoriesFilter READ categoriesFilter WRITE setCategoriesFilter RESET resetCategoriesFilter NOTIFY categoriesFilterChanged)
     Q_PROPERTY(KNSCore::Provider::Filter filter READ filter WRITE setFilter NOTIFY filterChanged)
     Q_PROPERTY(KNSCore::Provider::SortMode sortOrder READ sortOrder WRITE setSortOrder NOTIFY sortOrderChanged)
     Q_PROPERTY(QString searchTerm READ searchTerm WRITE setSearchTerm RESET resetSearchTerm NOTIFY searchTermChanged)
-    Q_PROPERTY(QObject *searchPresetModel READ searchPresetModel NOTIFY searchPresetModelChanged)
+    Q_PROPERTY(SearchPresetModel *searchPresetModel READ searchPresetModel NOTIFY searchPresetModelChanged)
 
     /**
      * Current state of the engine, the state con contain multiple operations
@@ -92,7 +94,7 @@ public:
         return busyState().toInt() != 0 && ((busyState() & BusyOperation::InstallingEntry) != BusyOperation::InstallingEntry);
     }
 
-    QObject *categories() const;
+    CategoriesModel *categories() const;
     Q_SIGNAL void categoriesChanged();
 
     QStringList categoriesFilter() const;
@@ -119,7 +121,7 @@ public:
     }
     Q_SIGNAL void searchTermChanged();
 
-    QObject *searchPresetModel() const;
+    SearchPresetModel *searchPresetModel() const;
     Q_SIGNAL void searchPresetModelChanged();
 
     Q_INVOKABLE void updateEntryContents(const KNSCore::Entry &entry);
@@ -163,7 +165,7 @@ public:
      * Uninstalls an entry. It reverses the steps which were performed
      * during the installation.
      *
-     * @param entry The entry to deinstall
+     * @param entry The entry to uninstall
      */
     Q_INVOKABLE void uninstall(const KNSCore::Entry &entry);
 
@@ -201,7 +203,7 @@ Q_SIGNALS:
      * enumerations.
      * @param errorCode Represents the specific type of error which has occurred
      * @param message A human-readable message which can be shown to the end user
-     * @param metadata Any additional data which might be hepful to further work out the details of the error (see KNSCore::Entry::ErrorCode for the
+     * @param metadata Any additional data which might be helpful to further work out the details of the error (see KNSCore::Entry::ErrorCode for the
      * metadata details)
      * @see KNSCore::Engine::signalErrorCode
      * @since 5.84
